.. change::
   :tags: bug, postgresql

    Added "TRUNCATE" to the list of keywords accepted by the
    Postgresql dialect as an "autocommit"-triggering keyword.
    Pull request courtesy Jacob Hayes.
